==> nextcloud-app-calendar-1%3A5.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/az.js <==
OC.L10N.register(
    "calendar",
    {
    "Hello," : "Salam,",
    "Cheers!" : "Şərəfə!",
    "Calendar" : "Təqvim",
    "Confirm" : "Təsdiq edin",
    "Today" : "Bu gün",
    "Day" : "Gün",
    "Week" : "Həftə",
    "Month" : "Ay",
    "Copy link" : "linki nüsxələ",
    "Edit" : "Dəyişiklik et",
    "Delete" : "Sil",
    "New calendar" : "Yeni təqvim",
    "Export" : "Çıxarış",
    "Name" : "Ad",
    "Deleted" : "Silinib",
    "Restore" : "Geri qaytar",
    "Delete permanently" : "Həmişəlik sil",
    "Hidden" : "Gizli",
    "Share link" : "Linki yayımla",
    "can edit" : "dəyişmək olar",
    "Save" : "Saxla",
    "Cancel" : "Dayandır",
    "Automatic" : "Avtomatik",
    "Actions" : "İşlər",
    "Location" : "Yerləşdiyiniz ünvan",
    "Description" : "Açıqlanma",
    "to" : "doğru",
    "Add" : "Əlavə etmək",
    "Monday" : "Bazar ertəsi",
    "Tuesday" : "Çərşənbə axşamı",
    "Wednesday" : "Çərşənbə",
    "Thursday" : "Cümə axşamı",
    "Friday" : "Cümə",
    "Saturday" : "Şənbə",
    "Sunday" : "Bazar",
    "Update" : "Yenilənmə",
    "Your email address" : "Sizin email ünvanı",
    "Email" : "Email",
    "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
    "Done" : "Edildi",
    "Accept" : "Qəbul et",
    "Decline" : "İmtina",
    "Attendees" : "İştirakçılar",
    "Remove group" : "Qrupu sil",
    "Repeat" : "Təkrar",
    "never" : "heç vaxt",
    "Subscribe" : "Abunə",
    "Personal" : "Şəxsi",
    "Details" : "Detallar",
    "Resources" : "Resurslar",
    "Close" : "Bağla",
    "Daily" : "Günlük",
    "Weekly" : "Həftəlik",
    "Other" : "Digər",
    "Status" : "Status",
    "Categories" : "Kateqoriyalar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A5.3.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/az.js <==
OC.L10N.register(
    "calendar",
    {
    "Hello," : "Salam,",
    "Cheers!" : "Şərəfə!",
    "Calendar" : "Təqvim",
    "Confirm" : "Təsdiq edin",
    "Today" : "Bu gün",
    "Day" : "Gün",
    "Week" : "Həftə",
    "Month" : "Ay",
    "Copy link" : "linki nüsxələ",
    "Edit" : "Dəyişiklik et",
    "Delete" : "Sil",
    "New calendar" : "Yeni təqvim",
    "Export" : "Çıxarış",
    "Name" : "Ad",
    "Deleted" : "Silinib",
    "Restore" : "Geri qaytar",
    "Delete permanently" : "Həmişəlik sil",
    "Hidden" : "Gizli",
    "Share link" : "Linki yayımla",
    "can edit" : "dəyişmək olar",
    "Save" : "Saxla",
    "Cancel" : "Dayandır",
    "Automatic" : "Avtomatik",
    "Actions" : "İşlər",
    "Update" : "Yenilənmə",
    "Location" : "Yerləşdiyiniz ünvan",
    "Description" : "Açıqlanma",
    "to" : "doğru",
    "Add" : "Əlavə etmək",
    "Monday" : "Bazar ertəsi",
    "Tuesday" : "Çərşənbə axşamı",
    "Wednesday" : "Çərşənbə",
    "Thursday" : "Cümə axşamı",
    "Friday" : "Cümə",
    "Saturday" : "Şənbə",
    "Sunday" : "Bazar",
    "Your email address" : "Sizin email ünvanı",
    "Back" : "Geri",
    "Email" : "Email",
    "seconds" : "saniyələr",
    "minutes" : "dəqiqələr",
    "hours" : "saatlar",
    "days" : "günlər",
    "weeks" : "həftələr",
    "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
    "Done" : "Edildi",
    "Accept" : "Qəbul et",
    "Decline" : "İmtina",
    "Attendees" : "İştirakçılar",
    "Remove group" : "Qrupu sil",
    "Repeat" : "Təkrar",
    "never" : "heç vaxt",
    "Resources" : "Resurslar",
    "Subscribe" : "Abunə",
    "Personal" : "Şəxsi",
    "Edit event" : "Hadisəni dəyişdir",
    "Close" : "Bağla",
    "Daily" : "Günlük",
    "Weekly" : "Həftəlik",
    "second" : "saniyə",
    "Other" : "Digər",
    "Status" : "Status",
    "Categories" : "Kateqoriyalar",
    "Details" : "Detallar"
},
"nplurals=2; plural=(n != 1);");
